@@ -1,4 +1,3 @@
-
 import logging
 import sys
 import subprocess
@@ -8,6 +7,7 @@ app = typer.Typer()
 
 logger = logging.getLogger()
 
+
 def build_pdf(
     target: str = typer.Argument(
         ...,
@@ -30,10 +30,12 @@ def build_pdf(
     typer.echo(f"Target folder: {target}")
     typer.echo("Invoking xelatex...")
     try:
-        XELATEX_CMD=f'cd {target}; latexmk -f -xelatex -synctex=1 -interaction=nonstopmode -file-line-error -latexoption="-shell-escape" index.tex'
+        XELATEX_CMD = f'cd {target}; latexmk -f -xelatex -synctex=1 -interaction=nonstopmode -file-line-error -latexoption="-shell-escape" index.tex'
         ret_val = subprocess.run(XELATEX_CMD, shell=True)
         if ret_val.returncode != 0:
-            typer.echo(f"mklatex returned with a non zero error code, but thePDF was still created")
+            typer.echo(
+                f"mklatex returned with a non zero error code, but thePDF was still created"
+            )
             typer.Exit(code=1)
     except ValueError as err:
         typer.echo(f"Fatal error while running mklatex")
