@@ -141,9 +141,12 @@ class Session:
 
     def get_template_download_link(self, template_id: str):
         """
-            Return the tempalte metadata based on id
+        Return the tempalte metadata based on id
         """
-        info = self.get_model(TEMPLATE_DOWNLOAD_URL.format(api_url=self.api_url, id=template_id), TemplateDownloadInfo)
+        url = TEMPLATE_DOWNLOAD_URL.format(api_url=self.api_url, id=template_id)
+        logging.info("resolved template download url as %s", url)
+        info = self.get_model(url, TemplateDownloadInfo)
+        logging.info("received download link %s", info.link)
         return info.link
 
     def user(self) -> MyUser:
