@@ -1,14 +1,17 @@
 from typing import List, Optional
 
-class SchemaOptionDefs():
+
+class SchemaOptionDefs:
     _passopts: List[str]
     _packages: List[str]
     _setup: List[str]
 
-    def __init__(self,
+    def __init__(
+        self,
         passopts: Optional[List[str]] = None,
         packages: Optional[List[str]] = None,
-        setup: Optional[List[str]] = None):
+        setup: Optional[List[str]] = None,
+    ):
         self._passopts = passopts
         self._packages = packages
         self._setup = setup
@@ -29,6 +32,7 @@ class SchemaOptionDefs():
     def in_template(self):
         return False
 
+
 class CustomTemplateDefs(SchemaOptionDefs):
     def __init__(self, *args, **kwargs):
         super(CustomTemplateDefs, self).__init__(*args, **kwargs)
