@@ -1,7 +1,8 @@
 from .SchemaOptionDefs import CustomTemplateDefs, SchemaOptionDefs
 from typing import Dict, Optional, Union
 
-class StringSchemaOption():
+
+class StringSchemaOption:
     def __init__(self):
         self.value_map: Dict[str, Union[SchemaOptionDefs, CustomTemplateDefs]] = {}
         self.default: Union[str, None] = None
@@ -15,7 +16,9 @@ class StringSchemaOption():
         self.default = name
         self.value_map["default"] = self.value_map[name]
 
-    def get(self, name: Optional[str] = None) -> Union[SchemaOptionDefs, CustomTemplateDefs]:
+    def get(
+        self, name: Optional[str] = None
+    ) -> Union[SchemaOptionDefs, CustomTemplateDefs]:
         if name is None and self.default is None:
             raise ValueError("No default option set")
         if name is not None and name not in self.value_map:
@@ -25,4 +28,4 @@ class StringSchemaOption():
         return self.value_map[self.default]
 
     def names(self):
-        return [k for k,v in self.value_map.items()]
+        return [k for k, v in self.value_map.items()]
