@@ -6,7 +6,9 @@ from .patch_local_images_from_tex_block import patch_local_images_from_tex_block
 from .localize_images_from_content_block import localize_images_from_content_block
 from .localize_images_from_output_block import localize_images_from_output_block
 from .localize_image_from_top_level_block import localize_image_from_top_level_block
-from .localize_references_from_content_block import localize_references_from_content_block
+from .localize_references_from_content_block import (
+    localize_references_from_content_block,
+)
 from .localize_hrefs_in_content import localize_hrefs_in_content
 from .get_fast_hash import get_fast_hash
 from .parse_cite_tag_from_bibtex import parse_cite_tag_from_bibtex
