@@ -10,7 +10,7 @@ from .regex import (
     OUTPUT_IMAGE_BLOCK_REGEX,
     OUTPUT_IMAGE_OXA_REGEX,
     OUTPUT_SVG_BLOCK_REGEX,
-    OUTPUT_SVG_OXA_REGEX
+    OUTPUT_SVG_OXA_REGEX,
 )
 from .patch_local_images_from_tex_block import patch_local_images_from_tex_block
 
@@ -28,7 +28,9 @@ def localize_images_from_output_block(assets_folder: str, output_version: BlockV
             else:
                 regex_matchers = [OUTPUT_SVG_BLOCK_REGEX, OUTPUT_SVG_OXA_REGEX]
 
-            patch = patch_local_images_from_tex_block(regex_matchers, output_summary.content)
+            patch = patch_local_images_from_tex_block(
+                regex_matchers, output_summary.content
+            )
             if patch is not None:
                 # TODO won't work for non image outputs or multi outputs with
                 # mixed image and non image
@@ -61,7 +63,9 @@ def localize_images_from_output_block(assets_folder: str, output_version: BlockV
                 content = fetch(output_summary.link).decode("utf-8")
             else:
                 content = output_summary.content
-            all_content = all_content + "\n\n" + r"\begin{verbatim}" + content + r"\end{verbatim}"
+            all_content = (
+                all_content + "\n\n" + r"\begin{verbatim}" + content + r"\end{verbatim}"
+            )
         else:
             logging.info("WARNING: Unknown Output Summary: %s", output_summary.kind)
             patch = None
