@@ -9,7 +9,11 @@ from .index import (
     get_model,
 )
 from ...client import Session
-from .regex import INLINE_CITATION_BLOCK_REGEX, INLINE_CITATION_OXA_REGEX, UNPIN_OXA_REGEX
+from .regex import (
+    INLINE_CITATION_BLOCK_REGEX,
+    INLINE_CITATION_OXA_REGEX,
+    UNPIN_OXA_REGEX,
+)
 from .run_regex_matchers import run_regex_matchers
 
 
@@ -26,7 +30,8 @@ def localize_references_from_content_block(
     patched_content = content
 
     matches = run_regex_matchers(
-        [INLINE_CITATION_BLOCK_REGEX, INLINE_CITATION_OXA_REGEX], content)
+        [INLINE_CITATION_BLOCK_REGEX, INLINE_CITATION_OXA_REGEX], content
+    )
     remote_paths = [m[1] for m in matches]
 
     for remote_path in remote_paths:
